Methods
=======

:program:`mumott` distinguishes :ref:`basis sets <basis_sets>`, :ref:`projectors <projectors>`, and :ref:`residual calculators <residual_calculators>`, which can be combined to implement different methods.

.. toctree::
   :maxdepth: 2

   basis_sets
   projectors
   residual_calculators

Utilities
---------
.. automodule:: mumott.methods.utilities.preconditioning
   :members:
